import xarray as xr


dir_path = "/gpfs/scratch/bsc32/bsc032050/ifsnemo_grib_post/"
mesh_file = dir_path + "production/mesh_NEMO_EERIE.nc"

# get values from mesh file
with xr.open_mfdataset(mesh_file).isel(t=0) as mesh:
    lon = mesh['glamv'].astype("float32", copy=False)
    lat = mesh['gphiv'].astype("float32", copy=False)
    lev = mesh['nav_lev'].astype("float32", copy=False)
    # compute transversal area
    e1ve3v  = (mesh['e3v_0']*mesh['e1v']).astype("float32", copy=False)

# create dataset with the coordinates
ds = xr.Dataset({'areav': e1ve3v.compute()})
# assign coords
ds = ds.assign_coords(
    lev=("z", lev.values),
    j=("y", ds.y.values+1),
    i=("x", ds.x.values+1),
    lat=(["y", "x"], lat.values),
    lon=(["y", "x"], lon.values),
)
# assign attributes
ds.lon.attrs = dict(standard_name="longitude", units="degrees_east")
ds.lat.attrs = dict(standard_name="latitude", units="degrees_north")
ds.areav.attrs = dict(long_name="Area perpendicular to v-speed", units="m2")
ds.lev.attrs = dict(standard_name="depth", long_name="ocean depth coordinate",
                    axis="Z", positive="down",  units="m")
ds.j.attrs = dict(long_name="cell index along second dimension", units="1")
ds.i.attrs = dict(long_name="cell index along first dimension", units="1")
# swap dimensions
ds = ds.swap_dims({"z": "lev", "y": "j", "x": "i"})

# save distances
ds.to_netcdf(dir_path+"intermediate/areav.nc")

