import iris

from esmvalcore.preprocessor import extract_shape


dir_path = "/gpfs/scratch/bsc32/bsc032050/ifsnemo_grib_post/intermediate/"
extract_region_kwargs = dict(start_longitude=-100, end_longitude=20,
                             start_latitude=-34.76, end_latitude=60)

extract_shape_kwargs = dict(shapefile=dir_path+"atlantic/atlantic.shp")


def extract_region(cube: iris.cube.Cube,
                   start_longitude: float, end_longitude: float,
                   start_latitude: float, end_latitude: float
                   ) -> iris.cube.Cube:
    """
    Extract a region from a cube on an irregular grid.
    Original function from ESMValTool, modified to avoid masking.
    """
    # Convert longitudes to valid range
    if start_longitude != 360.:
        start_longitude %= 360.
    if end_longitude != 360.:
        end_longitude %= 360.
    # Select coordinates inside the region
    lats = cube.coord('latitude').points
    lons = (cube.coord('longitude').points + 360.) % 360.
    if start_longitude <= end_longitude:
        select_lons = (lons >= start_longitude) & (lons <= end_longitude)
    else:
        select_lons = (lons >= start_longitude) | (lons <= end_longitude)
    if start_latitude <= end_latitude:
        select_lats = (lats >= start_latitude) & (lats <= end_latitude)
    else:
        select_lats = (lats >= start_latitude) | (lats <= end_latitude)
    selection = select_lats & select_lons
    # Crop the selection, but keep rectangular shape
    i_range, j_range = selection.nonzero()
    if i_range.size == 0:
        raise ValueError("No data points available in selected region")
    i_min, i_max = i_range.min(), i_range.max()
    j_min, j_max = j_range.min(), j_range.max()
    i_slice, j_slice = slice(i_min, i_max + 1), slice(j_min, j_max + 1)
    return cube[..., i_slice, j_slice]


cube = iris.load_cube(dir_path+"areav.nc")
cube = extract_region(cube, **extract_region_kwargs)
cube = extract_shape(cube, **extract_shape_kwargs)

iris.save(cube, dir_path+"areav_cutted.nc", fill_value=1e20)
